# typetype
Typing game made by Ahmet Ozer

To install: pip install typetype

To play: typetype

# About
typetype is a minimalistic command line typing game. I made this game becuase I couldn't find any command line typing games that I liked, so I decided to make one myself. I made this game in 1 week and worked on it during my trip to canada.
Since it is a minimalistic game, I did not include much text/instructions. In order to see the game's unwritten controls please read the Navigation section before playing the game.
# Cursor
If you would like to use the '|' cursor that I made, use the -cursor option when running the game
# Navigation
(read this section)

Mode Selection Pages:

use the arrow keys to change the selected game mode

the enter key will select the highlighted option

the delete key will go back to the previous game

the esc key will quit the game (if you are on the first page)


Inside The Game:

just type to play!

use the esc key to restart the game

if the time hasn't started yet, press * to return to the menu

Results/End Page:

you can use the esc key to quit the game



WIP
